==> hinemos_src_3.0.0.tar.gz: Hinemos_src-3.0.0/PerformanceEJB/src/com/clustercontrol/performance/operator/PercentageOfTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 1番目の要素が全体に占める割合を計算します。
 */
public class PercentageOfTotal extends SnmpOperator{
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;
		
		double targetDiff = getDifferenceValue("var0");
		
		double diffTotal = getDifferenceValueTotal();
		
		// 分母が0の場合（更新されていない場合）
		if(diffTotal == 0){
			return Double.NaN;
		}
		
		perfData = (double)targetDiff / diffTotal * 100.0D;
		
		return perfData;
	}
}

==> hinemos_src-3.1.3.tar.gz: Hinemos_src-3.1.3/PerformanceEJB/src/com/clustercontrol/performance/operator/PercentageOfTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 1番目の要素が全体に占める割合を計算します。
 */
public class PercentageOfTotal extends Operator{
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;
		
		double targetDiff = getDifferenceValue("var0");
		
		double diffTotal = getDifferenceValueTotal();
		
		// 分母が0の場合（更新されていない場合）
		if(diffTotal == 0){
			return Double.NaN;
		}
		
		perfData = (double)targetDiff / diffTotal * 100.0D;
		
		return perfData;
	}
}
